@@ -1,5 +1,5 @@
 phase.plot <-
-function (x, y, phases, arrow.size=0.05, arrow.lwd=2) {
+function (x, y, phases, arrow.size=0.05, arrow.lwd=2, arrow.col="black") {
   g=meshgrid(x, y)
   x=g$x
   y=g$y
@@ -7,6 +7,6 @@ function (x, y, phases, arrow.size=0.05, arrow.lwd=2) {
   dy=sin(phases)*arrow.size
   suppressWarnings(
     arrows(x - dx, y - dy, x + dx, y + dy, length=arrow.size, lwd=arrow.lwd, 
-           code=2))
+           col=arrow.col, code=2))
 }
 
